=======
History
=======

0.1.0 (2019-08-09)
------------------

* First release on PyPI.

0.2.0 (2020-03-04)
------------------

* Second release on PyPI.

0.2.1 (2020-03-08)
------------------

* Third release on PyPI.

0.2.2 (2020-03-08)
------------------

* PyPI release with updated documentation.

0.2.3 (2020-09-21)
------------------

* Improved search function to locate simTool notebook

0.3.1 (2021-06-14)
------------------

* Improved input data validation
* Added web service based cacheing support

0.3.2 (2021-09-22)
------------------

* Fixed for use outside of HUBzero environment

0.3.3 (2021-10-04)
------------------

* Improved automatic documentation generation
* Fixed Image value setting

0.3.4 (2022-05-10)
------------------

* Verify location of installed or published sim2L notebook
* Differentiate between missing path and wrong path type (file/directory)
* Stricter enforcement of param attributes
* Retain directory structure when saving results.
* Close open files to avoid file descriptor leakage
* Added magic functions needed to run notebooks in parallel (MPI)

